@@ -1,4 +1,7 @@
+import os
+
 from AnnotatedSentence.AnnotatedSentence import AnnotatedSentence
+from AnnotatedSentence.AnnotatedWord import AnnotatedWord
 from AnnotatedSentence.ViewLayerType import ViewLayerType
 from Corpus.FileDescription import FileDescription
 from ParseTree.ParseNode import ParseNode
@@ -6,6 +9,7 @@ from ParseTree.ParseTree import ParseTree
 from WordNet.WordNet import WordNet
 
 from AnnotatedTree.ParseNodeDrawable import ParseNodeDrawable
+from AnnotatedTree.Processor.Condition.IsEnglishLeafNode import IsEnglishLeafNode
 from AnnotatedTree.Processor.Condition.IsPredicateVerbNode import IsPredicateVerbNode
 from AnnotatedTree.Processor.Condition.IsTurkishLeafNode import IsTurkishLeafNode
 from AnnotatedTree.Processor.Condition.IsVerbNode import IsVerbNode
@@ -15,17 +19,19 @@ from AnnotatedTree.Processor.NodeDrawableCollector import NodeDrawableCollector
 class ParseTreeDrawable(ParseTree):
 
     __fileDescription: FileDescription
-    __name: str
 
     def __init__(self, fileDescription, path: str=None):
         if path is None:
             if isinstance(fileDescription, FileDescription):
                 self.__fileDescription = fileDescription
+                self.name = fileDescription.getRawFileName()
                 self.readFromFile(self.__fileDescription.getFileName(fileDescription.getPath()))
             elif isinstance(fileDescription, str):
+                self.name = os.path.split(fileDescription)[1]
                 self.readFromFile(fileDescription)
         else:
             self.__fileDescription = FileDescription(path, fileDescription.getExtension(), fileDescription.getIndex())
+            self.name = self.__fileDescription.getRawFileName()
             self.readFromFile(self.__fileDescription.getFileName(fileDescription.getPath()))
 
     def setFileDescription(self, fileDescription: FileDescription):
@@ -47,12 +53,6 @@ class ParseTreeDrawable(ParseTree):
             self.root = None
         inputFile.close()
 
-    def setName(self, name: str):
-        self.__name = name
-
-    def getName(self) -> str:
-        return self.__name
-
     def nextTree(self, count: int):
         if self.__fileDescription.nextFileExists(count):
             self.__fileDescription.addToIndex(count)
@@ -101,17 +101,31 @@ class ParseTreeDrawable(ParseTree):
         if self.root is not None and isinstance(self.root, ParseNodeDrawable):
             self.root.clearLayer(viewLayerType)
 
-    def generateAnnotatedSentence(self) -> AnnotatedSentence:
+    def generateAnnotatedSentence(self, language: str=None) -> AnnotatedSentence:
         sentence = AnnotatedSentence()
-        nodeDrawableCollector = NodeDrawableCollector(self.root, IsTurkishLeafNode())
-        leafList = nodeDrawableCollector.collect()
-        for parseNode in leafList:
-            if isinstance(parseNode, ParseNodeDrawable):
-                layers = parseNode.getLayerInfo()
-                for i in range(layers.getNumberOfWords()):
-                    sentence.addWord(layers.toAnnotatedWord(i))
+        if language is None:
+            nodeDrawableCollector = NodeDrawableCollector(self.root, IsTurkishLeafNode())
+            leafList = nodeDrawableCollector.collect()
+            for parseNode in leafList:
+                if isinstance(parseNode, ParseNodeDrawable):
+                    layers = parseNode.getLayerInfo()
+                    for i in range(layers.getNumberOfWords()):
+                        sentence.addWord(layers.toAnnotatedWord(i))
+        else:
+            nodeDrawableCollector = NodeDrawableCollector(self.root, IsEnglishLeafNode())
+            leafList = nodeDrawableCollector.collect()
+            for parseNode in leafList:
+                if isinstance(parseNode, ParseNodeDrawable):
+                    newWord = AnnotatedWord("{" + language + "=" + parseNode.getData().getName() + "}{posTag="
+                                            + parseNode.getParent().getData().getName() + "}")
+                    sentence.addWord(newWord)
         return sentence
 
+    def generateParseTree(self, surfaceForm: bool) -> ParseTree:
+        result = ParseTree(ParseNode(self.root.getData()))
+        self.root.generateParseNode(result.getRoot(), surfaceForm)
+        return result
+
     def extractNodesWithVerbs(self, wordNet: WordNet) -> list:
         nodeDrawableCollector = NodeDrawableCollector(self.root, IsVerbNode(wordNet))
         return nodeDrawableCollector.collect()
