@@ -12,7 +12,7 @@ class TreeBankDrawable(TreeBank):
 
     def __init__(self, folder: str = None, pattern: str = None):
         self.parseTrees = []
-        if str is not None:
+        if folder is not None:
             for root, dirs, files in os.walk(folder):
                 for file in files:
                     fileName = os.path.join(root, file)
